#! /usr/bin/python
# -*- coding: utf-8 -*-
#
# Przyklad programu do ladowania i wyswietlania obrazu trojwymiarowego
# wykorzystujacy biblioteki (moduly) ITK i VTK
# Signal and image processing lecture and workshop
#
# Example of image loading and visualisation with ITK and ITK
# Signal and image processing lecture and workshop
# 2016 by Piotr M. Szczypinski

import itk

# Tworzy obiekt do ladowania obrazu z pliku do pamieci komutera
# Creates an object for image loading
# IUC3 indicated image type to be created in the computer's memory
# I integer, UC = unsigned char (byte), 3 dimensions
reader = itk.ImageFileReader.IUC3.New()

# Laduje obraz
# Actually loads the image
reader.SetFileName( 'glowa.nii' )
reader.Update()

# Dla wygody przypisujemy obrazek do zmiennej 'image'
# The image is assigned to the 'image' variable
image = reader.GetOutput()

# Wypisuje informacje o rozmiarach obrazka
# Prints sizes (height, width and depth) of an image
image_size = image.GetLargestPossibleRegion().GetSize()
image_voxel_spacing = image.GetSpacing()
print 'Image size: '
print image_size
print 'Voxel spacing: '
print image_voxel_spacing

# Przyklad filtracji - wartosc bezwzgledna gradientu
# Example of image filtration - gradient magnitude
gradientFilter = itk.GradientMagnitudeRecursiveGaussianImageFilter.IUC3IUC3.New()
gradientFilter.SetInput( image )
gradientFilter.SetSigma( 2.0 )
gradientFilter.Update()
gradientImage = gradientFilter.GetOutput()

# Tworzy obiekt do zapis obrazu wynikowego do pliku
# Creates object for file writing
writer = itk.ImageFileWriter.IUC3.New()

# Ustawia co i gdzie ma byc zapisane
# Sets what and where to write
writer.SetInput( gradientImage )
writer.SetFileName( 'glowaKontur.nii' )

# Zapis obrazu wynikowego do pliku
# Actually saves image to a file
writer.Update()

# References:
# http://farsight-toolkit.org/wiki/FARSIGHT_Tutorials/Quick_Start
# http://paulnovo.us/wrapitktutorial
# https://itk.org/Wiki/ITK/Release_4/Wrapping/Examples
# https://itk.org/Wiki/ITK/Examples

