#! /usr/bin/python
# -*- coding: utf-8 -*-
#
# Przyklad programu do ladowania i wyswietlania modelu 3D
# wykorzystujacy biblioteke (modul) VTK
# Signal and image processing lecture and workshop
#
# Example of 3D model loading and visualisation with VTK
# Signal and image processing lecture and workshop
# 2016 by Piotr M. Szczypinski

import vtk

# Wczytywanie pliku STL
# Loading model from STL file
reader = vtk.vtkSTLReader()
reader.SetFileName( 'Ziarniak.stl' )
reader.Update()

# Przypisanie modelu do zmiennej 'model'
# Assigning model to 'model' variable
model = reader.GetOutput() 

# Wypisuje informacje o siatce modelu
# Prints info about model
print 'Triangles: '
print model.GetNumberOfCells()
print 'Vertices: '
print model.GetNumberOfPoints()

# Wyodrebnienie siatki polaczen
# Extracting edges
#edges = vtk.vtkExtractEdges()
#edges.SetInputConnection( reader.GetOutputPort() )
#edges.Update()

# Ustawienie wizualizacji/aktora
# Visualization/actor setup
mapper = vtk.vtkPolyDataMapper()
mapper.SetInputConnection(reader.GetOutputPort() )
#mapper.SetInputConnection(edges.GetOutputPort() )
actor = vtk.vtkActor()
actor.SetMapper(mapper)

# Tworzenie okna i silnika renderowania
# Creates a window and renderer
window = vtk.vtkRenderWindow()
renderer = vtk.vtkRenderer()
window.AddRenderer(renderer)
renderer.AddActor(actor)   

# Tworzenie interaktora, uzytkownik ma wplyw na wyswietlanie
# Creates an interactor
interactor = vtk.vtkRenderWindowInteractor()
interactor.SetRenderWindow(window)

# Ustawienia koloru tla
# Setting background color
renderer.SetBackground(.0, .0, .2)

# Ustawienie parametrow okna 
# Setting window name and size
window.SetWindowName("Model 3D")
window.SetSize(600, 600)

# Uruchomienie wyswietlania i interaktora
# Starting up
window.Render()
interactor.Start()

# Procedura zamykania okna
# Procedure to close the window
def close_window(interactor):
    window = interactor.GetRenderWindow()
    window.Finalize()
    interactor.TerminateApp()
    close_window(interactor)
del window, interactor


# References:
# http://www.vtk.org/Wiki/VTK/Examples/Python